@@ -29,7 +29,7 @@ class RateLimiterConfigurationDTO(BaseModel):
     cleanup_interval: int = Field(
         60, description="Interval for middleware cleanup (seconds)"
     )
-    ip_timeout: int = Field(300, description="Idle IP's timeout (seconds)")
+    idle_timeout: int = Field(300, description="Idle timeout (seconds)")
 
 
 class MiddlewareConfigurationDTO(BaseModel):
