@@ -141,7 +141,9 @@ class GoogleSecretManager(GoogleClientManager):
         )
 
         resource = Resource(
-            identifiers=[ResourceIdentifier(key="secret", name="Secret")],
+            identifiers=[
+                ResourceIdentifier(key="secret", name="Secret", url_slug="secret")
+            ],
             details={"secret_name": name},
         )
 
@@ -277,7 +279,9 @@ class GoogleSecretManager(GoogleClientManager):
         executed_at = datetime.now(tz=timezone.utc)
 
         resource = Resource(
-            identifiers=[ResourceIdentifier(key="secret", name="Secret")],
+            identifiers=[
+                ResourceIdentifier(key="secret", name="Secret", url_slug="secret")
+            ],
             details={"secret_name": name},
         )
 
