@@ -206,7 +206,11 @@ class GoogleCloudStorage(GoogleClientManager):
 
         resource = Resource(
             identifiers=[
-                ResourceIdentifier(key="object_storage", name="ObjectStorage")
+                ResourceIdentifier(
+                    key="object_storage",
+                    name="ObjectStorage",
+                    url_slug="object-storage",
+                )
             ],
             details={"object_location": location},
         )
@@ -302,7 +306,11 @@ class GoogleCloudStorage(GoogleClientManager):
 
         resource = Resource(
             identifiers=[
-                ResourceIdentifier(key="object_storage", name="ObjectStorage")
+                ResourceIdentifier(
+                    key="object_storage",
+                    name="ObjectStorage",
+                    url_slug="object-storage",
+                )
             ],
             details={"object_location": location},
         )
