@@ -5,7 +5,7 @@ from maleo_soma.enums.status import DataStatus as DataStatusEnum
 class DataStatus:
     status = Column(
         name="status",
-        type_=Enum(enums=DataStatusEnum, name="statustype"),
+        type_=Enum(DataStatusEnum, name="statustype", create_constraints=True),
         default=DataStatusEnum.ACTIVE,
         nullable=False,
     )
