@@ -2,7 +2,6 @@ import os
 from dotenv import load_dotenv
 from pydantic import BaseModel, Field
 from typing import Optional
-from maleo_soma.dtos.settings import Settings
 from maleo_soma.enums.environment import Environment
 from maleo_soma.enums.service import Service
 
@@ -24,10 +23,6 @@ class ServiceContext(BaseModel):
 
         return cls(environment=Environment(environment), key=Service(key))
 
-    @classmethod
-    def from_settings(cls, settings: Settings) -> "ServiceContext":
-        return cls(environment=settings.ENVIRONMENT, key=settings.SERVICE_KEY)
-
 
 class ServiceContextMixin(BaseModel):
     service_context: ServiceContext = Field(..., description="Service's context")
